@@ -1,37 +1,49 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
-//
-// +----------------------------------------------------------------------+
-// | Copyright (c) 1997-2005  Leandro Lucarella, Pierre-Alain Joye        |
-// +----------------------------------------------------------------------+
-// | This source file is subject to the New BSD license, That is bundled  |
-// | with this package in the file LICENSE, and is available through      |
-// | the world-wide-web at                                                |
-// | http://www.opensource.org/licenses/bsd-license.php                   |
-// | If you did not receive a copy of the new BSDlicense and are unable   |
-// | to obtain it through the world-wide-web, please send a note to       |
-// | pear-dev@lists.php.net so we can mail you a copy immediately.        |
-// +----------------------------------------------------------------------+
-// | Author: Baba Buehler <baba@babaz.com>                                |
-// |         Pierre-Alain Joye <pajoye@php.net>                           |
-// +----------------------------------------------------------------------+
+/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4 foldmethod=marker: */
+
+// {{{ Header
 
 /**
  * Generic time span handling class for PEAR
  *
  * PHP versions 4 and 5
  *
+ * LICENSE:
+ *
+ * Copyright (c) 1997-2005 Leandro Lucarella, Pierre-Alain Joye
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted under the terms of the BSD License.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+ * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+ * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+ * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ *
  * @category   Date and Time
  * @package    Date
  * @author     Leandro Lucarella <llucax@php.net>
  * @author     Pierre-Alain Joye <pajoye@php.net>
- * @copyright  1997-2005 Leandro Lucarella, Pierre-Alain Joye
- * @license    http://www.opensource.org/licenses/bsd-license.php  New BSD License
- * @version    CVS: $Id: Span.php,v 1.8 2005/11/15 00:16:40 pajoye Exp $
+ * @copyright  1997-2006 Leandro Lucarella, Pierre-Alain Joye
+ * @license    http://www.opensource.org/licenses/bsd-license.php
+ *             BSD License
+ * @version    CVS: $Id: Span.php,v 1.9 2006/11/21 17:38:15 firman Exp $
  * @link       http://pear.php.net/package/Date
  * @since      File available since Release 1.4
  */
 
+// }}}
+// {{{ Includes
+
 /**
  * Get the Date class
  */
@@ -42,6 +54,9 @@ require_once 'Date.php';
  */
 require_once 'Date/Calc.php';
 
+// }}}
+// {{{ Constants
+
 /**
  * Non Numeric Separated Values (NNSV) Input Format.
  *
@@ -64,6 +79,9 @@ require_once 'Date/Calc.php';
  */
 define('DATE_SPAN_INPUT_FORMAT_NNSV', 1);
 
+// }}}
+// {{{ Global Variables
+
 /**
  * Default time format when converting to a string.
  *
@@ -78,19 +96,24 @@ $GLOBALS['_DATE_SPAN_FORMAT']  = '%C';
  */
 $GLOBALS['_DATE_SPAN_INPUT_FORMAT'] = DATE_SPAN_INPUT_FORMAT_NNSV;
 
+// }}}
+// {{{ Class: Date_Span
+
 /**
  * Generic time span handling class for PEAR
  *
  * @author     Leandro Lucarella <llucax@php.net>
- * @copyright  1997-2005 The PHP Group
- * @license    http://www.opensource.org/licenses/bsd-license.php  New BSD License
- * @version    Release: 1.4.6
+ * @author     Pierre-Alain Joye <pajoye@php.net>
+ * @copyright  1997-2006 Leandro Lucarella, Pierre-Alain Joye
+ * @license    http://www.opensource.org/licenses/bsd-license.php
+ *             BSD License
+ * @version    Release: 1.4.7
  * @link       http://pear.php.net/package/Date
  * @since      Class available since Release 1.4
- *
- * @todo       Get and set default local input and output formats?
  */
-class Date_Span {
+class Date_Span
+{
+    // {{{ Properties
 
     /**
      * @var int
@@ -112,6 +135,9 @@ class Date_Span {
      */
     var $second;
 
+    // }}}
+    // {{{ Constructor
+
     /**
      * Constructor.
      *
@@ -129,6 +155,9 @@ class Date_Span {
         $this->set($time, $format);
     }
 
+    // }}}
+    // {{{ set()
+
     /**
      * Set the time span to a new value in a 'smart' way.
      *
@@ -165,6 +194,9 @@ class Date_Span {
         }
     }
 
+    // }}}
+    // {{{ setFromArray()
+
     /**
      * Set the time span from an array.
      *
@@ -207,6 +239,9 @@ class Date_Span {
         return $this->copy($tmp1);
     }
 
+    // }}}
+    // {{{ setFromString()
+
     /**
      * Set the time span from a string based on an input format.
      *
@@ -401,6 +436,9 @@ class Date_Span {
         return false;
     }
 
+    // }}}
+    // {{{ setFromSeconds()
+
     /**
      * Set the time span from a total number of seconds.
      *
@@ -426,6 +464,9 @@ class Date_Span {
         return true;
     }
 
+    // }}}
+    // {{{ setFromMinutes()
+
     /**
      * Set the time span from a total number of minutes.
      *
@@ -440,6 +481,9 @@ class Date_Span {
         return $this->setFromSeconds(round($minutes * 60));
     }
 
+    // }}}
+    // {{{ setFromHours()
+
     /**
      * Set the time span from a total number of hours.
      *
@@ -454,6 +498,9 @@ class Date_Span {
         return $this->setFromSeconds(round($hours * 3600));
     }
 
+    // }}}
+    // {{{ setFromDays()
+
     /**
      * Set the time span from a total number of days.
      *
@@ -468,6 +515,9 @@ class Date_Span {
         return $this->setFromSeconds(round($days * 86400));
     }
 
+    // }}}
+    // {{{ setFromDateDiff()
+
     /**
      * Set the span from the elapsed time between two dates.
      *
@@ -504,6 +554,9 @@ class Date_Span {
         return true;
     }
 
+    // }}}
+    // {{{ copy()
+
     /**
      * Set the time span from another time object.
      *
@@ -526,6 +579,9 @@ class Date_Span {
         }
     }
 
+    // }}}
+    // {{{ format()
+
     /**
      * Time span pretty printing (similar to Date::format()).
      *
@@ -694,6 +750,9 @@ class Date_Span {
         return $output;
     }
 
+    // }}}
+    // {{{ toSeconds()
+
     /**
      * Convert time span to seconds.
      *
@@ -707,6 +766,9 @@ class Date_Span {
             $this->minute * 60 + $this->second;
     }
 
+    // }}}
+    // {{{ toMinutes()
+
     /**
      * Convert time span to minutes.
      *
@@ -720,6 +782,9 @@ class Date_Span {
             $this->second / 60;
     }
 
+    // }}}
+    // {{{ toHours()
+
     /**
      * Convert time span to hours.
      *
@@ -733,6 +798,9 @@ class Date_Span {
             $this->second / 3600;
     }
 
+    // }}}
+    // {{{ toDays()
+
     /**
      * Convert time span to days.
      *
@@ -746,6 +814,9 @@ class Date_Span {
             $this->second / 86400;
     }
 
+    // }}}
+    // {{{ add()
+
     /**
      * Adds a time span.
      *
@@ -760,6 +831,9 @@ class Date_Span {
         );
     }
 
+    // }}}
+    // {{{ substract()
+
     /**
      * Subtracts a time span.
      *
@@ -781,6 +855,9 @@ class Date_Span {
         }
     }
 
+    // }}}
+    // {{{ equal()
+
     /**
      * Tells if time span is equal to $time.
      *
@@ -795,6 +872,9 @@ class Date_Span {
         return $this->toSeconds() == $time->toSeconds();
     }
 
+    // }}}
+    // {{{ greaterEqual()
+
     /**
      * Tells if this time span is greater or equal than $time.
      *
@@ -809,6 +889,9 @@ class Date_Span {
         return $this->toSeconds() >= $time->toSeconds();
     }
 
+    // }}}
+    // {{{ lowerEqual()
+
     /**
      * Tells if this time span is lower or equal than $time.
      *
@@ -823,6 +906,9 @@ class Date_Span {
         return $this->toSeconds() <= $time->toSeconds();
     }
 
+    // }}}
+    // {{{ greater()
+
     /**
      * Tells if this time span is greater than $time.
      *
@@ -837,6 +923,9 @@ class Date_Span {
         return $this->toSeconds() > $time->toSeconds();
     }
 
+    // }}}
+    // {{{ lower()
+
     /**
      * Tells if this time span is lower than $time.
      *
@@ -851,6 +940,9 @@ class Date_Span {
         return $this->toSeconds() < $time->toSeconds();
     }
 
+    // }}}
+    // {{{ compare()
+
     /**
      * Compares two time spans.
      *
@@ -876,6 +968,9 @@ class Date_Span {
         }
     }
 
+    // }}}
+    // {{{ isEmpty()
+
     /**
      * Tells if the time span is empty (zero length).
      *
@@ -886,6 +981,9 @@ class Date_Span {
         return !$this->day && !$this->hour && !$this->minute && !$this->second;
     }
 
+    // }}}
+    // {{{ setDefaultInputFormat()
+
     /**
      * Set the default input format.
      *
@@ -902,6 +1000,9 @@ class Date_Span {
         return $old;
     }
 
+    // }}}
+    // {{{ getDefaultInputFormat()
+
     /**
      * Get the default input format.
      *
@@ -914,6 +1015,9 @@ class Date_Span {
         return $GLOBALS['_DATE_SPAN_INPUT_FORMAT'];
     }
 
+    // }}}
+    // {{{ setDefaultFormat()
+
     /**
      * Set the default format.
      *
@@ -930,6 +1034,9 @@ class Date_Span {
         return $old;
     }
 
+    // }}}
+    // {{{ getDefaultFormat()
+
     /**
      * Get the default format.
      *
@@ -942,6 +1049,9 @@ class Date_Span {
         return $GLOBALS['_DATE_SPAN_FORMAT'];
     }
 
+    // }}}
+    // {{{ __clone()
+
     /**
      * Returns a copy of the object (workarround for PHP5 forward compatibility).
      *
@@ -956,4 +1066,18 @@ class Date_Span {
         $s->second = $this->second;
         return $s;
     }
+
+    // }}}
 }
+
+// }}}
+
+/*
+ * Local variables:
+ * mode: php
+ * tab-width: 4
+ * c-basic-offset: 4
+ * c-hanging-comment-ender-p: nil
+ * End:
+ */
+?>
\ No newline at end of file
